@@ -12,6 +12,7 @@ from typing import (
 
 from typing_extensions import NotRequired, Unpack
 
+import unique_sdk
 from unique_sdk._api_resource import APIResource
 from unique_sdk._request_options import RequestOptions
 
@@ -72,7 +73,7 @@ class Content(APIResource["Content"]):
 
     class SearchParams(RequestOptions):
         where: "Content.ContentWhereInput"
-        chatId: NotRequired[str]
+        chatId: NotRequired[str | None]
         includeFailedContent: NotRequired[bool]
 
     class ContentInfoParams(TypedDict):
@@ -81,10 +82,10 @@ class Content(APIResource["Content"]):
         This is used to retrieve information about content based on various filters.
         """
 
-        metadataFilter: dict
-        skip: NotRequired[int]
-        take: NotRequired[int]
-        filePath: NotRequired[str]
+        metadataFilter: NotRequired[dict[str, Any] | None]
+        skip: NotRequired[int | None]
+        take: NotRequired[int | None]
+        filePath: NotRequired[str | None]
 
     class CustomApiOptions(TypedDict):
         apiIdentifier: str
@@ -113,23 +114,25 @@ class Content(APIResource["Content"]):
         key: str
         title: Optional[str]
         mimeType: str
-        ownerType: str
-        ownerId: str
-        byteSize: Optional[int]
-        ingestionConfig: "Content.IngestionConfig"
-        metadata: dict[str, Any] | None = None
+        ownerType: NotRequired[str | None]
+        ownerId: NotRequired[str | None]
+        byteSize: NotRequired[int | None]
+        ingestionConfig: NotRequired["Content.IngestionConfig | None"]
+        metadata: NotRequired[dict[str, Any] | None]
 
     class UpsertParams(RequestOptions):
         input: "Content.Input"
-        scopeId: Optional[str]
-        chatId: Optional[str]
-        sourceOwnerType: str
-        storeInternally: bool
-        fileUrl: Optional[str]
+        scopeId: NotRequired[str | None]
+        chatId: NotRequired[str | None]
+        sourceOwnerType: NotRequired[str | None]
+        storeInternally: NotRequired[bool | None]
+        fileUrl: NotRequired[str | None]
 
     class UpdateParams(RequestOptions):
         contentId: NotRequired[str]
+        filePath: NotRequired[str]
         ownerId: NotRequired[str]
+        parentFolderPath: NotRequired[str]
         title: NotRequired[str]
         metadata: NotRequired[dict[str, str | None]]
 
@@ -161,11 +164,16 @@ class Content(APIResource["Content"]):
         expiredAt: str | None
 
     class PaginatedContentInfo(TypedDict):
+        contentInfo: List["Content.ContentInfo"]
+        totalCount: int
+
+    class PaginatedContentInfos(TypedDict):
         contentInfos: List["Content.ContentInfo"]
         totalCount: int
 
     class DeleteParams(RequestOptions):
         contentId: NotRequired[str]
+        filePath: NotRequired[str]
         chatId: NotRequired[str]
 
     class DeleteResponse(TypedDict):
@@ -178,6 +186,8 @@ class Content(APIResource["Content"]):
     updatedAt: str
     chunks: List[Chunk]
     metadata: Optional[Dict[str, Any]]
+    writeUrl: str
+    readUrl: str
 
     class MagicTableSheetTableColumn(TypedDict):
         columnId: str
@@ -284,9 +294,9 @@ class Content(APIResource["Content"]):
         user_id: str,
         company_id: str,
         **params: Unpack["Content.ContentInfoParams"],
-    ) -> "Content.PaginatedContentInfo":
+    ) -> "Content.PaginatedContentInfos":
         return cast(
-            Content.PaginatedContentInfo,
+            Content.PaginatedContentInfos,
             cls._static_request(
                 "post",
                 "/content/infos",
@@ -302,9 +312,9 @@ class Content(APIResource["Content"]):
         user_id: str,
         company_id: str,
         **params: Unpack["Content.ContentInfoParams"],
-    ) -> "Content.PaginatedContentInfo":
+    ) -> "Content.PaginatedContentInfos":
         return cast(
-            Content.PaginatedContentInfo,
+            Content.PaginatedContentInfos,
             await cls._static_request_async(
                 "post",
                 "/content/infos",
@@ -403,11 +413,29 @@ class Content(APIResource["Content"]):
         company_id: str,
         **params: Unpack["Content.UpdateParams"],
     ) -> "Content.ContentInfo":
+        content_id = cls.resolve_content_id_from_file_path(
+            user_id=user_id,
+            company_id=company_id,
+            content_id=params.get("contentId"),
+            file_path=params.get("filePath"),
+        )
+        owner_id = unique_sdk.Folder.resolve_scope_id_from_folder_path(
+            user_id,
+            company_id,
+            params.get("ownerId"),
+            params.get("parentFolderPath"),
+        )
+        params.pop("contentId", None)
+        params.pop("filePath", None)
+        params.pop("parentFolderPath", None)
+        if owner_id is not None:
+            params["ownerId"] = owner_id
+
         return cast(
             "Content.ContentInfo",
             cls._static_request(
                 "patch",
-                f"/content/{params.get('contentId')}",
+                f"/content/{content_id}",
                 user_id,
                 company_id,
                 params=params,
@@ -421,11 +449,29 @@ class Content(APIResource["Content"]):
         company_id: str,
         **params: Unpack["Content.UpdateParams"],
     ) -> "Content.ContentInfo":
+        content_id = cls.resolve_content_id_from_file_path(
+            user_id,
+            company_id,
+            params.get("contentId"),
+            params.get("filePath"),
+        )
+        owner_id = unique_sdk.Folder.resolve_scope_id_from_folder_path(
+            user_id,
+            company_id,
+            params.get("ownerId"),
+            params.get("parentFolderPath"),
+        )
+        params.pop("contentId", None)
+        params.pop("filePath", None)
+        params.pop("parentFolderPath", None)
+        if owner_id is not None:
+            params["ownerId"] = owner_id
+
         return cast(
             "Content.ContentInfo",
             await cls._static_request_async(
                 "patch",
-                f"/content/{params.get('contentId')}",
+                f"/content/{content_id}",
                 user_id,
                 company_id,
                 params=params,
@@ -437,17 +483,25 @@ class Content(APIResource["Content"]):
         cls,
         user_id: str,
         company_id: str,
-        **params: "Content.DeleteParams",
+        **params: Unpack["Content.DeleteParams"],
     ) -> "Content.DeleteResponse":
         """
         Deletes a content by its id or file path.
         """
+        content_id = cls.resolve_content_id_from_file_path(
+            user_id,
+            company_id,
+            params.get("contentId"),
+            params.get("filePath"),
+        )
+        params.pop("contentId", None)
+        params.pop("filePath", None)
 
         return cast(
             "Content.DeleteResponse",
             cls._static_request(
                 "delete",
-                f"/content/{params.get('contentId')}",
+                f"/content/{content_id}",
                 user_id,
                 company_id,
                 params=params,
@@ -459,17 +513,25 @@ class Content(APIResource["Content"]):
         cls,
         user_id: str,
         company_id: str,
-        **params: "Content.DeleteParams",
+        **params: Unpack["Content.DeleteParams"],
     ) -> "Content.DeleteResponse":
         """
         Async deletes a content by its id or file path.
         """
+        content_id = cls.resolve_content_id_from_file_path(
+            user_id,
+            company_id,
+            params.get("contentId"),
+            params.get("filePath"),
+        )
+        params.pop("contentId", None)
+        params.pop("filePath", None)
 
         return cast(
             "Content.DeleteResponse",
             await cls._static_request_async(
                 "delete",
-                f"/content/{params.get('contentId')}",
+                f"/content/{content_id}",
                 user_id,
                 company_id,
                 params=params,
@@ -483,10 +545,14 @@ class Content(APIResource["Content"]):
         company_id: str,
         content_id: str | None = None,
         file_path: str | None = None,
-    ) -> str:
+    ) -> str | None:
         """
         Returns the contentId to use: if content_id is provided, returns it;
         if not, but file_path is provided, resolves and returns the id for that file path.
+
+        Returns:
+            str: The resolved content ID.
+            None: Failed to resolve a content ID (e.g., file_path not found or not provided).
         """
         if content_id:
             return content_id
@@ -496,9 +562,12 @@ class Content(APIResource["Content"]):
                 company_id=company_id,
                 filePath=file_path,
             )
+            content_infos = file_info.get("contentInfo")
             resolved_id = (
-                file_info.get("contentInfo")[0].get("id")
+                content_infos[0].get("id")
                 if file_info.get("totalCount", 0) > 0
+                and content_infos is not None
+                and len(content_infos) > 0
                 else None
             )
             if not resolved_id:
